/*
Copyright 2010-2012 Michael Braiman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package ui.auto.core.context;

import java.net.MalformedURLException;
import java.net.URL;

import org.openqa.selenium.Platform;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.firefox.FirefoxProfile;
import org.openqa.selenium.firefox.internal.ProfilesIni;
import org.openqa.selenium.remote.DesiredCapabilities;
import org.openqa.selenium.remote.RemoteWebDriver;


public enum BrowserDriverType {
	InternetExplorerDriver (org.openqa.selenium.ie.InternetExplorerDriver.class,"internet explorer"),
    FirefoxDriver (org.openqa.selenium.firefox.FirefoxDriver.class,"firefox"),
    ChromeDriver (org.openqa.selenium.chrome.ChromeDriver.class,"chrome"),
    HtmlUnitDriver (org.openqa.selenium.htmlunit.HtmlUnitDriver.class,"html unit");
	
	private Class<?> driver_class;
	private String browserName;
	
	public WebDriver getNewDriver() {
		System.setProperty("webdriver.chrome.driver", "c:/chromedriver/chromedriver.exe");
		WebDriver driver = null;
		try {
			if(this.equals(FirefoxDriver)){
				ProfilesIni allProfiles=new ProfilesIni();
				FirefoxProfile profile=allProfiles.getProfile("Selenium");
				driver=new org.openqa.selenium.firefox.FirefoxDriver(profile);
			} else {
				driver=(WebDriver) driver_class.newInstance();
			}	
		} catch (Exception e) {
			throw new RuntimeException(e.getLocalizedMessage());
		}
		return driver;
	}

	public WebDriver getNewRemoteDriver(String hubUrl,Platform platform,String version){
		DesiredCapabilities cap=new DesiredCapabilities();
		cap.setBrowserName(browserName);
		cap.setPlatform(platform);
		cap.setVersion(version);
		RemoteWebDriver driver;
		try {
			driver =new RemoteWebDriver(new URL(hubUrl),cap);
		} catch (MalformedURLException e) {
			throw new RuntimeException(e.getLocalizedMessage());
		}
		return driver;
	}
	
	private BrowserDriverType(Class<?> driver_class,String browserName) {
		this.driver_class=driver_class;
		this.browserName=browserName;
	}
	
//	@Test
//	public static void test(){
//		WebDriver dr=BrowserDriverType.ChromeDriver.getNewDriver();
//		dr.get("http://www.google.com");
//		dr.quit();
//		
//		dr=BrowserDriverType.FirefoxDriver.getNewRemoteDriver("http://192.10.1.1:4444/wd/hub",Platform.ANY,null);
//		dr.get("http://www.yahoo.com");
//		dr.quit();
//		
//	}
    
}