/*
Copyright 2010-2012 Michael Braiman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package ui.auto.core.context;

import java.net.URL;
import java.net.URLConnection;
import java.util.concurrent.TimeUnit;

import org.openqa.selenium.Platform;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebDriver.Window;

import ui.auto.core.data.DataSet;
import ui.auto.core.data.TestDataDefinition;
import ui.auto.core.pageobjects.PageObject;




public class TestContext {
	private WebDriver driver;
	private String browser;
	private int findElementTimeOut=1000; //in milliseconds	
	private int waitForUrlTimeOut=10000; //in milliseconds 
	private PageObject currentPageObject;
	private TestDataDefinition testDataDefinition;
	private DataSet dataSet;
	private String serverUrl;

	public TestContext(TestDataDefinition testDataDefinition, DataSet dataSet,boolean createLazily) {
		this.testDataDefinition=testDataDefinition;
		this.dataSet=dataSet;
		this.browser=dataSet.getBrowser().name();
		if (!createLazily) init();
	}
	
	public TestContext(BrowserDriverType browser,String serverUrl,String urlPrefix,String user,String password) {
		testDataDefinition=new TestDataDefinition(serverUrl,urlPrefix,user,password);
		this.browser=browser.name();
		this.serverUrl=serverUrl;
		driver=browser.getNewDriver();
		isWebLive(serverUrl,10000);
		driver.get(serverUrl);
		setFindElementTimeOut(findElementTimeOut);
	}
	
	
	public String getServerUrl(){
		if (testDataDefinition!=null){
			return testDataDefinition.getServerUrl();
		}
		return serverUrl;
	}
	
	private void isWebLive(String sUrl,int timeOut){
		try {
			URL url=new URL(sUrl);
			URLConnection urlConn=url.openConnection();
			urlConn.setConnectTimeout(timeOut);
			urlConn.connect();
		} catch (Exception e) {
			throw new RuntimeException(e.getLocalizedMessage());
		}
	}
	
	public void init(){
		if (driver==null) {
			String hubUrl=dataSet.getHubUrl();
			Platform platform= dataSet.getPlatform();
			String version=dataSet.getVersion();
			if (hubUrl!=null && !hubUrl.trim().equals("")){
				driver=dataSet.getBrowser().getNewRemoteDriver(hubUrl, platform, version);
			} else {
				driver=dataSet.getBrowser().getNewDriver();
			}
			isWebLive(testDataDefinition.getServerUrl(), 10000);
			driver.get(testDataDefinition.getServerUrl());
			setFindElementTimeOut(findElementTimeOut);
		}		
	}
	
	
	public TestDataDefinition getTestDataDefinition() {
		return testDataDefinition;
	}

	public DataSet getDataSet() {
		return dataSet;
	}

	public int getFindElementTimeOut() {
		return findElementTimeOut;
	}

	public void setFindElementTimeOut(int findElementTimeOut) {
		this.findElementTimeOut = findElementTimeOut;
		if (driver!=null)
			driver.manage().timeouts().implicitlyWait(findElementTimeOut, TimeUnit.MILLISECONDS);
	}

	public int getWaitForUrlTimeOut() {
		return waitForUrlTimeOut;
	}

	public void setWaitForUrlTimeOut(int waitForUrlTimeOut) {
		this.waitForUrlTimeOut = waitForUrlTimeOut;
	}

	public PageObject getCurrentPageObject() {
		return currentPageObject;
	}

	public void setCurrentPageObject(PageObject currentPageObject) {
		this.currentPageObject = currentPageObject;
	}

	public String getBrowser() {
		return browser;
	}

	public WebDriver getDriver() {
		init();
		return driver;
	}
	
	public Window getWindow(){
		init();
		return driver.manage().window();
	}

	public void close(){
		if (driver!=null) this.driver.close();
	}
	
	public void quit(){
		if (driver!=null) this.driver.quit();
	}
	
	@Override
	public String toString(){
		return browser + " : " + dataSet.getFilePath() + " : id=" +Thread.currentThread().getId(); 
	}	
}
	
