/*
Copyright 2010-2012 Michael Braiman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package ui.auto.core.data;

import java.util.ArrayList;
import java.util.List;

import org.openqa.selenium.Platform;

import ui.auto.core.context.BrowserDriverType;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamImplicit;


@XStreamAlias("data-set")
public class DataSet {
	@XStreamAsAttribute
	private BrowserDriverType browser;
	@XStreamAsAttribute
	private String hubUrl;
	@XStreamAsAttribute
	private Platform platform;
	@XStreamAsAttribute
	private String version; 
	@XStreamImplicit
	@XStreamAlias("file")
	private List<String> filePath=new ArrayList<String>();
	
	public DataSet(BrowserDriverType browser, String filePath) {
		this.browser = browser;
		this.filePath.add(filePath);
	}

	public BrowserDriverType getBrowser() {
		return browser;
	}

	public List<String> getFilePath() {
		return filePath;
	}
	
	public String getHubUrl() {
		return hubUrl;
	}

	public Platform getPlatform() {
		return platform;
	}

	public String getVersion() {
		return version;
	}

	@Override
	public String toString(){
		String out="";
		for (String s:filePath){
			out=out + s +";";
		}
		return out;
	}
	
	public DataFile getDataFile(){
		return getDataFile(0);
	}
	
	public DataFile getDataFile(int index){
		return new DataFile(filePath.get(index));
	}
	
}