/*
Copyright 2010-2012 Michael Braiman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package ui.auto.core.pageobjects;

import org.openqa.selenium.By;
import org.openqa.selenium.support.PageFactory;

import ui.auto.core.context.TestContext;
import ui.auto.core.data.DataPersistence;
import ui.auto.core.utils.Utils;

import com.thoughtworks.xstream.annotations.XStreamOmitField;


public class PageObject extends DataPersistence{
	@XStreamOmitField
	protected TestContext context;
	@XStreamOmitField
	private String currentUrl;
	
	
	public void  initPage(TestContext context){
		this.context=context;
		context.setCurrentPageObject(this);
		currentUrl=context.getDriver().getCurrentUrl();
		AjaxVisibleElementLocatorFactory ajaxVisibleElementLocatorFactory=new AjaxVisibleElementLocatorFactory(context.getDriver(),10);
		PageFactory.initElements(new ComponentFieldDecorator(ajaxVisibleElementLocatorFactory,this),this);
	}
	
	public void initPage(TestContext context,String expectedUrl){
		initPage(context);
		if (expectedUrl!=null) waitForUrl(expectedUrl);
	}
	
	protected PageObject(){
		//make sure to run initPage before using this or derived PageObject
	}
	
	protected PageObject(TestContext context){
		initPage(context);
	}
	
	
	protected PageObject(TestContext context,String expectedUrl){
		initPage(context,expectedUrl);
	}
	
	
	private void lookForExceptions(){
		if (context.getDriver().findElement(By.tagName("h1")).getText().contains("HTTP Status")){
			throw new Error("Server Exception is triggered!");
		}
	}
	
	public void waitForUrl(String expectedUrl){
		long endTime=System.currentTimeMillis() + context.getWaitForUrlTimeOut();
		while (System.currentTimeMillis()<endTime) {
			if (context.getDriver().getCurrentUrl().contains(expectedUrl)) {
				currentUrl=context.getDriver().getCurrentUrl();
				lookForExceptions();
				return;
			}
			Utils.Sleep(100);
		} 
		throw new Error("Expected url:" + expectedUrl + " is not displayed!");	
	}
	
	
	public boolean waitForUrlToChange(){
		long endTime=System.currentTimeMillis() + context.getWaitForUrlTimeOut();
		boolean exitWhile=false;
		while (System.currentTimeMillis()<endTime && !exitWhile) {
			if (!context.getDriver().getCurrentUrl().contains(currentUrl)) exitWhile=true;
			Utils.Sleep(100);
		} 
		lookForExceptions();
		return exitWhile;
	}
	
}
